
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>

#define EMOJI_PRAYER 0x1F64F

void decode_utf8(const uint8_t *input, uint32_t *output, size_t limit) {
	size_t offset = 0;
	while (true) {
		// Check to prevent buffer overflow
		if (offset == limit - 1) break;
		
		// Read the next character
		uint8_t character = *input++;
		
		// Stop when we reach the null terminator
		if (character == 0) {
			break;
		}
		
		if (character < 0x80) output[offset++] = character;
		else if (0xC0 <= character && character < 0xE0) {
			uint32_t value = (character & 0x1F) << 6;
			value |= *input++ & 0x3F;
			output[offset++] = value;
		}
		else if (0xE0 <= character && character < 0xF0) {
			uint32_t value = (character & 0xF) << 12;
			value |= (*input++ & 0x3F) << 6;
			value |= *input++ & 0x3F;
			output[offset++] = value;
		}
		else if (0xF0 <= character && character < 0xF8) {
			uint32_t value = (character & 7) << 18;
			value |= (*input++ & 0x3F) << 12;
			value |= (*input++ & 0x3F) << 6;
			value |= *input++ & 0x3F;
			output[offset++] = value;
		}
		else {
			// Stop if we encounter an invalid character
			break;
		}
	}
	
	// Add a null terminator
	output[offset++] = 0;
}

void encode_utf8(const uint32_t *input, uint8_t *output, size_t limit) {
	size_t offset = 0;
	while (true) {
		// Check to prevent buffer overflow
		if (offset == limit - 1) break;
		
		// Read the next character
		uint32_t character = *input++;
		
		// Stop when we reach the null terminator
		if (character == 0) {
			break;
		}
		
		if (character < 0x80) output[offset++] = character;
		else if (character < 0x800) {
			output[offset++] = (character >> 6) | 0xC0;
			output[offset++] = (character & 0x3F) | 0x80;
		}
		else if (character < 0x10000) {
			output[offset++] = (character >> 12) | 0xE0;
			output[offset++] =  ((character >> 6) & 0x3F) | 0x80;
			output[offset++] = (character & 0x3F) | 0x80;
		}
		else {
			output[offset++] = (character >> 18) | 0xF0;
			output[offset++] = ((character >> 12) & 0x3F) | 0x80;
			output[offset++] = ((character >> 6) & 0x3F) | 0x80;
			output[offset++] = (character & 0x3F) | 0x80;
		}
	}
	
	// Add a null terminator
	output[offset++] = 0;
}

void print_flag() {
	system("cat flag.txt");
}

bool service() {
	uint8_t output[256];
	uint8_t input[256];
	uint32_t decoded[256];
	
	if (!fgets(input, sizeof(input), stdin)) {
		return false;
	}
	
	decode_utf8(input, decoded, sizeof(decoded) / sizeof(decoded[0]));
	encode_utf8(decoded, output, sizeof(output));
	printf("%s", output);
	
	return decoded[0] != EMOJI_PRAYER;
}

int main() {
	setbuf(stdin, NULL);
	setbuf(stdout, NULL);
	setbuf(stderr, NULL);
	
	while (service());
	return 0;
}
